@@ -4,5 +4,5 @@ pub mod parser;
 pub mod reader;
 pub mod workers;
 
-pub use reader::{Reader,PointerType};
+pub use reader::{Reader,PointerType,Write};
 use std::time::Instant;
\ No newline at end of file
